#ifndef __PHYSICS_
#define __PHYSICS_

#include "model.h"
#include "diagrams.h"
#include "syst2.h"



extern int  subproc_f, subproc_sq;

extern char  modelmenu[STRSIZ];
extern int  maxmodel;

extern int  nsub, ndiagr,n_model;


#endif
